@@ -14,10 +14,16 @@ if __name__ == "__main__":
         bearer_token=open("keys/twitter-bearer-token").read().strip(),
     )  # splitting means that it recursively splits a large text into sentences and analyzes each individually
 
-    # """
+    scores = darthvader.summary(*args)  # latest date to get news from
+    print("Total\n--")
+    pprint(scores)
+
+    """
     scores = darthvader.news_summary(*args)  # latest date to get news from
     print("News\n--")
     pprint(scores)
-    scores = darthvader.twitter_summary(*args, size=200)  # latest date to get news from
+
+    scores = darthvader.twitter_summary(*args, size=100)  # latest date to get news from
     print("\nTwitter\n--")
     pprint(scores)
+    """
\ No newline at end of file
